@@ -191,7 +191,7 @@ pub enum PollResult {
 ///
 /// #[derive(CandidType, Deserialize)]
 /// struct CreateCanisterResult {
-///   canister_id: candid::Principal,
+///   canister_id: Principal,
 /// }
 ///
 /// # fn create_identity() -> impl ic_agent::Identity {
@@ -572,7 +572,7 @@ impl Agent {
         }
     }
 
-    async fn read_state_raw(
+    pub async fn read_state_raw(
         &self,
         paths: Vec<Vec<Label>>,
         effective_canister_id: Principal,
