@@ -122,5 +122,5 @@ pub use agent::{
 pub use identity::{Identity, Signature};
 pub use request_id::{to_request_id, RequestId, RequestIdError};
 
-pub(crate) use crate::ic_types::hash_tree;
+pub use crate::ic_types::hash_tree;
 pub use ic_types;
